Class: NameError::Message
- Inherits:
-
Object
- Object
- NameError::Message
- Defined in:
- lib/akephalos/server.rb
Overview
In ruby-1.8.7 and later, the message for a NameError exception is lazily evaluated. There are, however, different implementations of this between ruby and jrby, so we realize these messages when sending over DRb.
Instance Method Summary collapse
Instance Method Details
#_dump ⇒ Object
10 11 12 |
# File 'lib/akephalos/server.rb', line 10 def _dump to_s end |